@@ -2,7 +2,7 @@
 %%% File    : ejabberd_doc.erl
 %%% Purpose : Options documentation generator
 %%%
-%%% ejabberd, Copyright (C) 2002-2025   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2026   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -199,7 +199,7 @@ get_module_apitags(M) ->
     Tags = [C#ejabberd_commands.tags || C <- AllCommands, C#ejabberd_commands.module == M],
     TagsClean =
         lists:sort(
-            misc:lists_uniq(
+            lists:uniq(
                 lists:flatten(Tags))),
     TagsStrings = [atom_to_list(C) || C <- TagsClean],
     TagFiltering =
