@@ -5,7 +5,7 @@
 %%% Created : 27 Feb 2004 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2025   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2026   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -33,9 +33,11 @@
 	 accept/1, receive_headers/1, recv_file/2,
 	 listen_opt_type/1, listen_options/0,
 	 apply_custom_headers/2]).
-
+-export([get_url/4, get_auto_url/2, get_auto_urls/2, find_handler_port_path/2]).
 -export([init/3]).
 
+-deprecate({get_auto_url, 2}).
+
 -include("logger.hrl").
 -include_lib("xmpp/include/xmpp.hrl").
 -include("ejabberd_http.hrl").
@@ -126,7 +128,10 @@ init(SockMod, Socket, Opts) ->
 			     true -> {SockMod, Socket}
 			  end,
     SockPeer =  proplists:get_value(sock_peer_name, Opts, none),
-    RequestHandlers = proplists:get_value(request_handlers, Opts, []),
+    RequestHandlers0 = proplists:get_value(request_handlers, Opts, []),
+    RequestHandlers = ejabberd_hooks:run_fold(http_request_handlers_init,
+                                              RequestHandlers0,
+                                              [Opts]),
     ?DEBUG("S: ~p~n", [RequestHandlers]),
 
     {ok, RE} = re:compile(<<"^(?:\\[(.*?)\\]|(.*?))(?::(\\d+))?$">>),
@@ -718,7 +723,7 @@ file_format_error(Reason) ->
 url_decode_q_split_normalize(Path) ->
     {NPath, Query} = url_decode_q_split(Path),
     LPath = normalize_path([NPE
-		    || NPE <- str:tokens(misc:uri_decode(NPath), <<"/">>)]),
+		    || NPE <- str:tokens(uri_string:percent_decode(NPath), <<"/">>)]),
     {LPath, Query}.
 
 % Code below is taken (with some modifications) from the yaws webserver, which
@@ -868,6 +873,78 @@ apply_custom_headers(Headers, CustomHeaders) ->
 		   maps:from_list(CustomHeaders)),
     Doctype ++ maps:to_list(M).
 
+%%%--------------------------------
+%%%-export([get_url/4, get_auto_url/2]).
+
+get_url(M, bosh, Tls, Host) ->
+    get_url(M, Tls, Host, bosh_service_url, mod_bosh);
+get_url(M, websocket, Tls, Host) ->
+    get_url(M, Tls, Host, websocket_url, ejabberd_http_ws);
+get_url(M, Option, Tls, Host) ->
+    get_url(M, Tls, Host, Option, M).
+
+get_url(M, Tls, Host, Option, Handler) ->
+    case get_url_preliminar(M, Tls, Host, Option, Handler) of
+        undefined -> undefined;
+        Url -> misc:expand_keyword(<<"@HOST@">>, Url, Host)
+    end.
+
+get_url_preliminar(M, Tls, Host, Option, Handler) ->
+    case gen_mod:get_module_opt(Host, M, Option) of
+        undefined -> undefined;
+        auto -> get_auto_url(Tls, Handler);
+        <<"auto">> -> get_auto_url(Tls, Handler);
+        U when is_binary(U) -> U
+    end.
+
+get_auto_url(Tls, Handler) ->
+    case get_auto_urls(Tls, Handler) of
+        [] -> undefined;
+        [{_ThisTls, Url} | _] -> Url
+    end.
+
+-spec get_auto_urls(boolean() | any, atom()) -> [{boolean(), binary()}].
+
+get_auto_urls(Tls, Handler) ->
+    Paths = find_handler_port_path(Tls, Handler),
+    [prepare_url(Path, Handler) || Path <- Paths].
+
+prepare_url({ThisTls, Port, Path}, Handler) ->
+            Protocol = case {ThisTls, Handler} of
+                           {false, ejabberd_http_ws} -> <<"ws">>;
+                           {true, ejabberd_http_ws} -> <<"wss">>;
+                           {false, _} -> <<"http">>;
+                           {true, _} -> <<"https">>
+                       end,
+            {ThisTls,
+             <<Protocol/binary,
+              "://@HOST@:",
+              (integer_to_binary(Port))/binary,
+              "/",
+              (str:join(Path, <<"/">>))/binary,
+              "/">>}.
+
+find_handler_port_path(Tls, Handler) ->
+    Paths = lists:map(
+      fun({{Port, _, _},
+           ejabberd_http,
+           #{tls := ThisTls, request_handlers := Handlers}})
+            when is_integer(Port) and ((Tls == any) or (Tls == ThisTls)) ->
+              find_handler_port_path_option(ThisTls, Port, Handler, Handlers);
+         (_) ->
+              []
+      end, ets:tab2list(ejabberd_listener)),
+    lists:append(Paths).
+
+find_handler_port_path_option(ThisTls, Port, Handler, Handlers) ->
+    lists:filtermap(fun({Path, H}) when H == Handler ->
+                            {true, {ThisTls, Port, Path}};
+                        ({_Path, _Handler}) ->
+                            false
+                    end, Handlers).
+
+%%%--------------------------------
+
 % The following code is mostly taken from yaws_ssl.erl
 
 toupper(C) when C >= $a andalso C =< $z -> C - 32;
